#PBS -l nodes=1:ppn=16
#PBS -l walltime=13:0:0

from ase.io import read
from ase.optimize.bfgs import BFGS
from gpaw import GPAW, PoissonSolver, Mixer, FermiDirac
from gpaw.xc.libvdwxc import vdw_df, vdw_df2, vdw_df_cx
from gpaw.utilities import h2gpts
from gpaw.utilities.timing import ParallelTimer

system = read('1BNA-Hadd-22Na.xyz')
system.center(vacuum=4.0)
system.pbc = 1

system.calc = GPAW(txt='gpaw.txt',
                   mode='lcao',
                   basis='sz(dzp)',
                   nbands='105%',
                   xc=vdw_df_cx(),
                   parallel=dict(sl_auto=True),
                                 #augment_grids=True,
                                 #band=1),
                   occupations=FermiDirac(0.1),
                   gpts=h2gpts(0.25, system.get_cell(), idiv=16),
                   poissonsolver=PoissonSolver(relax='GS'),
                   timer=ParallelTimer(),
                   mixer=Mixer(0.05, 5, 100.0))
#system.get_potential_energy()

opt = BFGS(system, trajectory='opt.traj', logfile='opt.log',
           maxstep=0.8)
opt.run(fmax=0.05)
